<?php

namespace WePublish\CDN_YES\Inc;

use WePublish\CDN_YES\Inc\Setting as Setting;
use function WePublish\CDN_YES\Inc\cdn_static as cdn_static;

class Plugin {

	/**
	 * 插件设置API
	 */
	private \WePublish\CDN_YES\Inc\Setting $settings_api;

	public function __construct() {
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		$this->settings_api = new Setting;
	}

	/**
	 * 加载插件
	 */
	public function plugins_loaded(): void {
		add_action( 'admin_init', array( $this, 'load_setting' ) );
		add_action( 'admin_menu', array( $this, 'load_setting_page' ) );
		add_action( 'init', array( $this, 'load_plugin' ) );
	}

	/**
	 * 挂载设置项
	 */
	public function load_setting(): void {
		$sections = array(
			array(
				'id'    => 'wp_cdn_yes_setting',
				'title' => __( '设置', 'wp-cdn-yes' )
			),
			array(
				'id'    => 'wp_cdn_yes_about',
				'title' => __( '关于', 'wp-cdn-yes' )
			)
		);

		$fields = array(
			'wp_cdn_yes_setting' => array(
				array(
					'name'    => 'cdn_static',
					'label'   => __( '静态文件CDN加速', 'wp-cdn-yes' ),
					'value'   => __( '启用', 'wp-cdn-yes' ),
					'desc'    => __( '该功能正处于实验阶段，可一键将前台静态资源使用公共CDN加速，如开启后访问异常，请关掉它并与我反馈。', 'wp-cdn-yes' ),
					'type'    => 'checkbox',
					'default' => 'on'
				)
			),
			'wp_cdn_yes_about' => array(
				array(
					'name'  => 'about',
					'label' => __( '关于插件', 'wp-cdn-yes' ),
					'type'  => 'html',
					'html'  => __( '<h4>官网：<a href="https://wepublish.cn" target="_blank">https://wepublish.cn</a> | 隐私协议：<a href="https://wepublish.cn" target="_blank">暂无</a></h4><p><b>WP-CDN-Yes</b>是WordPress本土化的一部分，其作用是提供刷新CDN缓存，静态加速。</p><p>该插件由<b>WePublish@耗子</b>负责维护，使用问题与反馈交流QQ群：<a href="https://jq.qq.com/?_wv=1027&k=I1oJKSTH">12370907</a></p>', 'wp-cdn-yes' )
				)
			)
		);


		//set sections and fields
		$this->settings_api->set_sections( $sections );
		$this->settings_api->set_fields( $fields );

		//initialize them
		$this->settings_api->admin_init();
	}

	/**
	 * 挂载设置页面
	 */
	public function load_setting_page(): void {
		add_options_page( esc_html__( 'WP-CDN-Yes', 'wp-cdn-yes' ), esc_html__( 'WP-CDN-Yes', 'wp-cdn-yes' ), 'manage_options', 'wp_cdn_yes', array(
			$this,
			'plugin_page'
		) );
		add_filter( 'plugin_action_links', function ( $links, $file ) {
			if ( 'wp-cdn-yes/wp-cdn-yes.php' !== $file ) {
				return $links;
			}
			$settings_link = '<a href="' . add_query_arg( array( 'page' => 'wp_cdn_yes' ), admin_url( 'options-general.php' ) ) . '">' . esc_html__( '设置', 'wp-cdn-yes' ) . '</a>';
			array_unshift( $links, $settings_link );

			return $links;
		}, 10, 2 );
	}

	/**
	 * 设置页面模版
	 */
	public function plugin_page(): void {
		echo '<h1>WP-CDN-Yes</h1><span style="float: right;">By: WePublish@耗子</span>';
		echo '<div class="wrap">';
		settings_errors();

		$this->settings_api->show_navigation();
		$this->settings_api->show_forms();

		echo '</div>';
	}

	/**
	 * 加载插件功能
	 */
	public function load_plugin(): void {
		$cdn_static = $this->settings_api->get_option('cdn_static', 'wp_cdn_yes_about', 'on');
		if ( $cdn_static == 'on' ) {
			cdn_static();
		}
	}
}
